/*
 * Test case for PreparedStmt
 * Need first to run this query on the database connection is made
 * to:
 * CREATE TABLE t1 (c1 int, c2 char(1000));
 * INSERT INTO t1 values(generate_series(1,500000), 'aaaa');
 */
#include <libpq-fe.h>

#define DB_CONN_STR		"host=localhost dbname=postgres"
#define SQL_FETCH_AA	"select c1 from t1 where c1 < $1"

int
main(int argc, char *argv[])
{
	PGconn*         conn;
	PGresult*       res;
	int				ntuples;
	const char* paramValues[1];

	if ((conn = PQconnectdb(DB_CONN_STR)) == NULL)
		fprintf(stderr, "Connect to '%s' failed", DB_CONN_STR);

	if (PQstatus(conn) != CONNECTION_OK)
		fprintf(stderr, "Connect to '%s' failed: %s",
			DB_CONN_STR, PQerrorMessage(conn));

	if ((res = PQprepare(conn, "sql_fetch_aa",
						 SQL_FETCH_AA, 1, NULL)) == NULL)
		fprintf(stderr, "Preparing statement '%s' failed",
			SQL_FETCH_AA);

	if (PQresultStatus(res) != PGRES_COMMAND_OK)
		fprintf(stderr, "Preparing statement '%s' failed: %s",
			SQL_FETCH_AA, PQerrorMessage(conn));

	paramValues[0] = "1000";

	res = PQexecPrepared(conn, "sql_fetch_aa", 1,
						 paramValues,
						 NULL, NULL, 0);
	if (PQresultStatus(res) != PGRES_TUPLES_OK)
	{
		fprintf(stderr, "fetch data failed: %s",
				PQerrorMessage(conn));
		return 1;
	}

	ntuples = PQntuples(res);
	PQclear(res);

	PQfinish(conn);

	return 0;
}
